"""
Handles /identities endpoint
"""

import requests
from mailersend.base import base

class NewSenderIdentities(base.NewAPIClient):
    """
    Instantiates the /identities endpoint object
    """

    # you shall not
    pass

    def get_identities(self, domain_id=None, page=None, limit=25):
        """
        Get all sender identities

        @params:
          domain_id (string)
          page (int)
          limit (int): Min: `10`, Max: `100`, default is 25
        """

        passed_arguments = locals()
        query_params = {}

        for key, value in passed_arguments.items():
            if key != "self" and value is not None:
                query_params[key] = value

        request = requests.get(
            f"{self.api_base}/identities",
            headers=self.headers_default,
            params=query_params,
        )

        return f"{request.status_code}\n{request.text}"
    
    def get_identity(self, identity_id):
        """
        Get a single sender identity

        @params:
          identity_id (string)
        """

        request = requests.get(
            f"{self.api_base}/identities/{identity_id}",
            headers=self.headers_default,
        )

        return f"{request.status_code}\n{request.text}"
    
    def add_identitity(self, domain_id, name, email, reply_to_email=None, reply_to_name=None, add_note=False, personal_note=None):
        """
        Add a sender identity

        @params:
          domain_id (string)
          name (string) - Max 191 characters
          email (string) - Max 191 characters, unique
          reply_to_email (string)
          reply_to_name (string)
          add_note (boolean)
          personal_note (string)
        """

        data = {
            "domain_id": domain_id, 
            "name": name,
            "email": email
        }

        if reply_to_email != None:
            data["reply_to_email"] = reply_to_email

        if reply_to_name != None:
            data["reply_to_name"] = reply_to_name
        
        if add_note == True:
            data["add_note"] = add_note
            data["personal_note"] = personal_note

        request = requests.post(
            f"{self.api_base}/identities",
            headers=self.headers_default,
            json=data,
        )

        return f"{request.status_code}\n{request.text}"
    
    def update_identitity(self, identity_id, domain_id=None, name=None, email=None, reply_to_email=None, reply_to_name=None, add_note=False, personal_note=None):
        """
        Update a sender identity

        @params:
          identity_id (string)
          domain_id (string)
          name (string) - Max 191 characters
          email (string) - Max 191 characters, unique
          reply_to_email (string)
          reply_to_name (string)
          add_note (boolean)
          personal_note (string)
        """
        
        passed_arguments = locals()
        data = {}

        for key, value in passed_arguments.items():
            if key != "self" and key != "identity_id" and value is not None:
                data[key] = value

        request = requests.put(
            f"{self.api_base}/identities/{identity_id}",
            headers=self.headers_default,
            json=data,
        )

        return f"{request.status_code}\n{request.text}"
    
    def delete_identity(self, identity_id):
        """
        Delete a sender identity

        @params:
          identity_id (string)
        """
        
        request = requests.delete(
            f"{self.api_base}/identities/{identity_id}",
            headers=self.headers_default,
        )

        return request.text


"""
Handles /email-verification endpoint
"""

import requests
from mailersend.base import base


class NewEmailVerification(base.NewAPIClient):
    """
    Instantiates the /email-verification endpoint object
    """

    # you shall not
    pass

    def get_all_lists(self, page=1, limit=25):
        """
        Returns all email verification lists
        :param page: int
        :param limit: int
        """
        query_params = {"page": page, "limit": limit}

        request = requests.get(
            f"{self.api_base}/email-verification",
            headers=self.headers_default,
            params=query_params,
        )

        return f"{request.status_code}\n{request.text}"

    def get_list(self, email_verification_id):
        """
        Retrieve single email verification list
        :type email_verification_id: object
        """

        query_params = {"email_verification_id": email_verification_id}

        request = requests.get(
            f"{self.api_base}/email-verification",
            headers=self.headers_default,
            params=query_params,
        )

        return f"{request.status_code}\n{request.text}"

    def create_list(self, name, emails):
        """
        Create email verification list
        :param name: str
        :param emails: list
        :return:
        """

        data = {"name": name, "emails": emails}

        request = requests.post(
            f"{self.api_base}/email-verification",
            headers=self.headers_default,
            json=data,
        )

        return f"{request.status_code}\n{request.text}"

    def verify_list(self, email_verification_id):
        """
        Verify an email verification list
        :type email_verification_id: str
        """

        request = requests.get(
            f"{self.api_base}/email-verification/{email_verification_id}/verify",
            headers=self.headers_default,
        )

        return f"{request.status_code}\n{request.text}"

    def get_list_results(self, email_verification_id):
        """
        Get the result for each individual email of an email verification list
        :type email_verification_id: str
        """

        request = requests.get(
            f"{self.api_base}/email-verification/{email_verification_id}/results",
            headers=self.headers_default,
        )

        return f"{request.status_code}\n{request.text}"



"""
Handles /api-quota endpoint
"""

import requests
from mailersend.base import base


class NewApiQuota(base.NewAPIClient):
    """
    Instantiates the /api-quota endpoint object
    """

    pass

    def get_quota(self, page=1, limit=25, verified=False):
        query_params = {"page": page, "limit": limit, "verified": verified}

        request = requests.get(
            f"{self.api_base}/api-quota",
            headers=self.headers_default,
            params=query_params,
        )

        return request.text
